@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,6 +19,10 @@ using namespace Akonadi::Search;
 
 AkonadiSearchDebugWidget::AkonadiSearchDebugWidget(QWidget *parent)
     : QWidget(parent)
+    , mPlainTextEditor(new QPlainTextEdit(this))
+    , mSearchPathComboBox(new Akonadi::Search::AkonadiSearchDebugSearchPathComboBox(this))
+    , mLineEdit(new KLineEdit(this))
+    , mSearchButton(new QPushButton(QStringLiteral("Search"), this))
 {
     auto mainLayout = new QVBoxLayout(this);
 
@@ -26,24 +30,20 @@ AkonadiSearchDebugWidget::AkonadiSearchDebugWidget(QWidget *parent)
     mainLayout->addLayout(hbox);
     auto lab = new QLabel(QStringLiteral("Item identifier:"), this);
     hbox->addWidget(lab);
-    mLineEdit = new KLineEdit(this);
     mLineEdit->setTrapReturnKey(true);
     mLineEdit->setClearButtonEnabled(true);
     mLineEdit->setObjectName(QStringLiteral("lineedit"));
     connect(mLineEdit, &KLineEdit::textChanged, this, &AkonadiSearchDebugWidget::slotSearchLineTextChanged);
     hbox->addWidget(mLineEdit);
 
-    mSearchPathComboBox = new Akonadi::Search::AkonadiSearchDebugSearchPathComboBox(this);
     hbox->addWidget(mSearchPathComboBox);
     mSearchPathComboBox->setObjectName(QStringLiteral("searchpathcombo"));
 
-    mSearchButton = new QPushButton(QStringLiteral("Search"), this);
     mSearchButton->setObjectName(QStringLiteral("searchbutton"));
     connect(mSearchButton, &QPushButton::clicked, this, &AkonadiSearchDebugWidget::slotSearch);
     hbox->addWidget(mSearchButton);
     mSearchButton->setEnabled(false);
 
-    mPlainTextEditor = new QPlainTextEdit(this);
     new AkonadiSearchSyntaxHighlighter(mPlainTextEditor->document());
     mPlainTextEditor->setReadOnly(true);
     mainLayout->addWidget(mPlainTextEditor);
@@ -52,9 +52,7 @@ AkonadiSearchDebugWidget::AkonadiSearchDebugWidget(QWidget *parent)
     connect(mLineEdit, &KLineEdit::returnPressed, this, &AkonadiSearchDebugWidget::slotSearch);
 }
 
-AkonadiSearchDebugWidget::~AkonadiSearchDebugWidget()
-{
-}
+AkonadiSearchDebugWidget::~AkonadiSearchDebugWidget() = default;
 
 void AkonadiSearchDebugWidget::slotSearchLineTextChanged(const QString &text)
 {
