@@ -1,12 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "akonadisearchsyntaxhighlighter.h"
-#include <QRegExp>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#else
+#endif
 using namespace Akonadi::Search;
 
 AkonadiSearchSyntaxHighlighter::AkonadiSearchSyntaxHighlighter(QTextDocument *doc)
@@ -15,12 +16,11 @@ AkonadiSearchSyntaxHighlighter::AkonadiSearchSyntaxHighlighter(QTextDocument *do
     init();
 }
 
-AkonadiSearchSyntaxHighlighter::~AkonadiSearchSyntaxHighlighter()
-{
-}
+AkonadiSearchSyntaxHighlighter::~AkonadiSearchSyntaxHighlighter() = default;
 
 void AkonadiSearchSyntaxHighlighter::highlightBlock(const QString &text)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     for (const Rule &rule : std::as_const(m_rules)) {
         const QRegExp expression(rule.pattern);
         int index = expression.indexIn(text);
@@ -30,6 +30,16 @@ void AkonadiSearchSyntaxHighlighter::highlightBlock(const QString &text)
             index = expression.indexIn(text, index + length);
         }
     }
+#else
+    for (const Rule &rule : std::as_const(m_rules)) {
+        QRegularExpressionMatchIterator matchIterator = rule.pattern.globalMatch(text);
+        while (matchIterator.hasNext()) {
+            QRegularExpressionMatch match = matchIterator.next();
+            setFormat(match.capturedStart(), match.capturedLength(), rule.format);
+        }
+    }
+
+#endif
 }
 
 void AkonadiSearchSyntaxHighlighter::init()
@@ -79,7 +89,11 @@ void AkonadiSearchSyntaxHighlighter::init()
     testType << QStringLiteral("\\bS");
     testType << QStringLiteral("\\bL");
     for (const QString &s : std::as_const(testType)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QRegExp regex(s, Qt::CaseSensitive);
+#else
+        const QRegularExpression regex(s);
+#endif
         m_rules.append(Rule(regex, testFormat));
     }
 }
